# -*- coding: utf-8 -*-
# Generated by Django 1.11.3 on 2017-08-02 17:30
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('dj_experiment', '0003_auto_20170802_1708'),
    ]

    operations = [
    ]
