# -*- coding: utf-8 -*-
# Generated by Django 1.11.3 on 2017-08-02 17:31
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    replaces = [('dj_experiment', '0002_auto_20170802_1206'), ('dj_experiment', '0003_auto_20170802_1708'), ('dj_experiment', '0004_auto_20170802_1230')]

    dependencies = [
        ('dj_experiment', '0001_initial_squashed_0006_auto_20170802_0904'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='catalog',
            name='xperiment',
        ),
        migrations.AddField(
            model_name='catalog',
            name='xperiments',
            field=models.ForeignKey(default='', on_delete=django.db.models.deletion.CASCADE, related_name='catalogs', to='dj_experiment.Experiment'),
            preserve_default=False,
        ),
        migrations.AlterField(
            model_name='experiment',
            name='data_dir',
            field=models.CharField(default='./', max_length=250),
        ),
        migrations.AlterField(
            model_name='experiment',
            name='separator',
            field=models.CharField(default='.', max_length=1),
        ),
        migrations.AlterField(
            model_name='experiment',
            name='data_dir',
            field=models.CharField(default=b'RCM data', max_length=250),
        ),
        migrations.AlterField(
            model_name='experiment',
            name='separator',
            field=models.CharField(default=b'_', max_length=1),
        ),
    ]
