# -*- coding: utf-8 -*-
from django.conf.urls import url
from django.views.generic import TemplateView

from . import views

urlpatterns = [
    url(
        regex="^experiment/~create/$",
        view=views.ExperimentCreateView.as_view(),
        name='experiment_create',
    ),
    url(
        regex="^experiment/(?P<pk>\d+)/~delete/$",
        view=views.ExperimentDeleteView.as_view(),
        name='experiment_delete',
    ),
    url(
        regex="^experiment/(?P<pk>\d+)/$",
        view=views.ExperimentDetailView.as_view(),
        name='experiment_detail',
    ),
    url(
        regex="^experiment/(?P<pk>\d+)/~update/$",
        view=views.ExperimentUpdateView.as_view(),
        name='experiment_update',
    ),
    url(
        regex="^experiment/$",
        view=views.ExperimentListView.as_view(),
        name='experiment_list',
    ),
    url(
        regex="^case/~create/$",
        view=views.CaseCreateView.as_view(),
        name='case_create',
    ),
    url(
        regex="^case/(?P<pk>\d+)/~delete/$",
        view=views.CaseDeleteView.as_view(),
        name='case_delete',
    ),
    url(
        regex="^case/(?P<pk>\d+)/$",
        view=views.CaseDetailView.as_view(),
        name='case_detail',
    ),
    url(
        regex="^case/(?P<pk>\d+)/~update/$",
        view=views.CaseUpdateView.as_view(),
        name='case_update',
    ),
    url(
        regex="^case/$",
        view=views.CaseListView.as_view(),
        name='case_list',
    ),
    url(
        regex="^fieldgroup/~create/$",
        view=views.FieldGroupCreateView.as_view(),
        name='fieldgroup_create',
    ),
    url(
        regex="^fieldgroup/(?P<pk>\d+)/~delete/$",
        view=views.FieldGroupDeleteView.as_view(),
        name='fieldgroup_delete',
    ),
    url(
        regex="^fieldgroup/(?P<pk>\d+)/$",
        view=views.FieldGroupDetailView.as_view(),
        name='fieldgroup_detail',
    ),
    url(
        regex="^fieldgroup/(?P<pk>\d+)/~update/$",
        view=views.FieldGroupUpdateView.as_view(),
        name='fieldgroup_update',
    ),
    url(
        regex="^fieldgroup/$",
        view=views.FieldGroupListView.as_view(),
        name='fieldgroup_list',
    ),
    url(
        regex="^value/~create/$",
        view=views.ValueCreateView.as_view(),
        name='value_create',
    ),
    url(
        regex="^value/(?P<pk>\d+)/~delete/$",
        view=views.ValueDeleteView.as_view(),
        name='value_delete',
    ),
    url(
        regex="^value/(?P<pk>\d+)/$",
        view=views.ValueDetailView.as_view(),
        name='value_detail',
    ),
    url(
        regex="^value/(?P<pk>\d+)/~update/$",
        view=views.ValueUpdateView.as_view(),
        name='value_update',
    ),
    url(
        regex="^value/$",
        view=views.ValueListView.as_view(),
        name='value_list',
    ),
    url(
        regex="^catalog/~create/$",
        view=views.CatalogCreateView.as_view(),
        name='catalog_create',
    ),
    url(
        regex="^catalog/(?P<pk>\d+)/~delete/$",
        view=views.CatalogDeleteView.as_view(),
        name='catalog_delete',
    ),
    url(
        regex="^catalog/(?P<pk>\d+)/$",
        view=views.CatalogDetailView.as_view(),
        name='catalog_detail',
    ),
    url(
        regex="^catalog/(?P<pk>\d+)/~update/$",
        view=views.CatalogUpdateView.as_view(),
        name='catalog_update',
    ),
    url(
        regex="^catalog/$",
        view=views.CatalogListView.as_view(),
        name='catalog_list',
    ),
]
